@@ -28,17 +28,19 @@
 #include <ktexteditor/editor.h>
 #include "ktexteditor/view.h"
 
-#include <KService>
 #include <KAboutData>
 #include <KSharedConfig>
 
-#include <ktexteditor/application.h>
+#include <KTextEditor/Application>
+#include <KTextEditor/MainWindow>
 #include <KTextEditor/Command>
-#include <draft/templateinterface2.h>
 
 #include <QList>
 #include <QPointer>
 #include <QMap>
+#include <QScopedPointer>
+
+class QStringListModel;
 
 class KateCmd;
 class KateModeManager;
@@ -56,6 +58,7 @@ class KateSpellCheckManager;
 class KateWordCompletionModel;
 class KateAbstractInputModeFactory;
 class KateKeywordCompletionModel;
+class KateDefaultColors;
 
 namespace KTextEditor
 {
@@ -67,10 +70,9 @@ namespace KTextEditor
  * or view stay around, here is the place to put things
  * which are needed and shared by all this objects ;)
  */
-class KTEXTEDITOR_EXPORT EditorPrivate : public KTextEditor::Editor, public KTextEditor::TemplateScriptRegistrar
+class KTEXTEDITOR_EXPORT EditorPrivate : public KTextEditor::Editor
 {
     Q_OBJECT
-    Q_INTERFACES(KTextEditor::TemplateScriptRegistrar)
 
     friend class KTextEditor::Editor;
 
@@ -109,13 +111,13 @@ public:
      * @param parent parent object
      * @return created KTextEditor::Document
      */
-    KTextEditor::Document *createDocument(QObject *parent);
+    KTextEditor::Document *createDocument(QObject *parent) Q_DECL_OVERRIDE;
 
     /**
      * Returns a list of all documents of this editor.
      * @return list of all existing documents
      */
-    QList<KTextEditor::Document *> documents()
+    QList<KTextEditor::Document *> documents() Q_DECL_OVERRIDE
     {
         return m_documents.keys();
     }
@@ -126,16 +128,17 @@ public:
      * the hosting application.
      * @param application application object
      */
-    void setApplication(KTextEditor::Application *application)
+    void setApplication(KTextEditor::Application *application) Q_DECL_OVERRIDE
     {
-        m_application = application;
+        // switch back to dummy application?
+        m_application = application ? application : &m_dummyApplication;
     }
 
     /**
      * Current hosting application, if any set.
      * @return current application object or nullptr
      */
-    KTextEditor::Application *application() const
+    KTextEditor::Application *application() const Q_DECL_OVERRIDE
     {
         return m_application;
     }
@@ -148,7 +151,7 @@ public:
      * return the about data
      * @return about data of this editor part
      */
-    const KAboutData &aboutData() const
+    const KAboutData &aboutData() const Q_DECL_OVERRIDE
     {
         return m_aboutData;
     }
@@ -162,7 +165,7 @@ public:
      * to the editor, but not saved anywhere automagically, call
      * writeConfig to save them
     */
-    void configDialog(QWidget *parent);
+    void configDialog(QWidget *parent) Q_DECL_OVERRIDE;
 
     /**
      * Number of available config pages
@@ -170,14 +173,14 @@ public:
      * and the embedding app should use the configDialog () instead
      * @return number of config pages
      */
-    int configPages() const;
+    int configPages() const Q_DECL_OVERRIDE;
 
     /**
      * returns config page with the given number,
      * config pages from 0 to configPages()-1 are available
      * if configPages() > 0
      */
-    KTextEditor::ConfigPage *configPage(int number, QWidget *parent);
+    KTextEditor::ConfigPage *configPage(int number, QWidget *parent) Q_DECL_OVERRIDE;
 
     /**
      * Kate Part Internal stuff ;)
@@ -232,7 +235,7 @@ public:
     {
         return m_dirWatch;
     }
-    
+
     /**
      * The global configuration of katepart, e.g. katepartrc
      * @return global shared access to katepartrc config
@@ -333,35 +336,31 @@ public:
     }
 
     /**
-      * global instance of the language-aware keyword completion model
-      * @return global instance of the keyword completion model
-      */
-     KateKeywordCompletionModel *keywordCompletionModel () { return m_keywordCompletionModel; }
+     * Global instance of the language-aware keyword completion model
+     * @return global instance of the keyword completion model
+     */
+    KateKeywordCompletionModel *keywordCompletionModel () {
+        return m_keywordCompletionModel;
+    }
 
     /**
      * query for command
      * @param cmd name of command to query for
      * @return found command or 0
      */
-    KTextEditor::Command *queryCommand(const QString &cmd) const;
+    KTextEditor::Command *queryCommand(const QString &cmd) const Q_DECL_OVERRIDE;
 
     /**
      * Get a list of all registered commands.
      * \return list of all commands
      */
-    QList<KTextEditor::Command *> commands() const;
+    QList<KTextEditor::Command *> commands() const Q_DECL_OVERRIDE;
 
     /**
      * Get a list of available commandline strings.
      * \return commandline strings
      */
-    QStringList commandList() const;
-
-    /**
-     *  TemplateScriptRegistrar interface
-     */
-    KTextEditor::TemplateScript *registerTemplateScript(QObject *owner, const QString &script);
-    void unregisterTemplateScript(KTextEditor::TemplateScript *templateScript);
+    QStringList commandList() const Q_DECL_OVERRIDE;
 
     /**
      * Copy text to clipboard an remember it in the history
@@ -387,11 +386,44 @@ public:
         return m_documents.values();
     }
 
+    /**
+     * Dummy main window to be null safe.
+     * @return dummy main window
+     */
+    KTextEditor::MainWindow *dummyMainWindow()
+    {
+        return &m_dummyMainWindow;
+    }
+
     /**
      * @return list of available input mode factories
      */
     QList<KateAbstractInputModeFactory *> inputModeFactories();
 
+    /**
+     * Default colors, once constructed, as expensive
+     * @return default colors
+     */
+    const KateDefaultColors &defaultColors() const
+    {
+        return *m_defaultColors;
+    }
+
+    /**
+     * Search pattern history shared among simple/power search instances.
+     */
+    QStringListModel *searchHistoryModel();
+
+    /**
+     * Replace pattern history shared among simple/power search instances.
+     */
+    QStringListModel *replaceHistoryModel();
+
+    /**
+     * Call this function to store the history models to the application config.
+     */
+    void saveSearchReplaceHistoryModels();
+
 Q_SIGNALS:
     /**
      * Emitted if the history of clipboard changes via copyToClipboard
@@ -399,7 +431,7 @@ Q_SIGNALS:
     void clipboardHistoryChanged();
 
 protected:
-    bool eventFilter(QObject *, QEvent *);
+    bool eventFilter(QObject *, QEvent *) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void updateColorPalette();
@@ -495,15 +527,36 @@ private:
      */
     QStringList m_clipboardHistory;
 
+    /**
+     * Dummy application object to be null safe
+     */
+    KTextEditor::Application m_dummyApplication;
+
     /**
      * access to application
      */
     QPointer<KTextEditor::Application> m_application;
 
+    /**
+     * Dummy main window to be null safe
+     */
+    KTextEditor::MainWindow m_dummyMainWindow;
+
     /**
      * input modes map
      */
     QMap<KTextEditor::View::InputMode, KateAbstractInputModeFactory *> m_inputModeFactories;
+
+    /**
+     * default colors
+     */
+    QScopedPointer<KateDefaultColors> m_defaultColors;
+
+    /**
+     * Shared history models for search & replace.
+     */
+    QStringListModel *m_searchHistoryModel;
+    QStringListModel *m_replaceHistoryModel;
 };
 
 }
